==> bulletinHD-2.1.zip: xoops_trust_path/modules/bulletin/language/persian/main.php <==
<?php /* English Translation by Marcelo Yuji Himoro <http://yuji.ws> */

//          index.php          //
define("_MD_PRINTER","صفحه پرینت خبر");
define("_MD_SENDSTORY","ارسال این خبر برای دوستان");
define("_MD_READMORE","ادامه نوشته...");
define("_MD_COMMENTS","0 نظر");
define("_MD_ONECOMMENT","1 نظر");
define("_MD_BYTESMORE","%s بیت در ادامه");
define("_MD_NUMCOMMENTS","%s نظر");

//          submit.php          //
define("_MD_SUBMITNEWS","ارسال خبر");
define("_MD_TITLE","موضوع");
define("_MD_TOPIC","شاخه");
define("_MD_THESCOOP","متن خبر");
define("_MD_NOTIFYPUBLISH","وقتی این خبر تایید شد مرا با ایمیل مطلع کن");
define("_MD_POST","پست");
define("_MD_GO","ارسال");
define("_MD_THANKS","نوشته شما دریافت شد. لطفا  صبر کنید تا مدیر سایت آن را برسی و تایید و منتشر کند."); //submission of news article
define("_MD_THANKS_AUTOAPPROVE","از ارسال شما متشکریم.");
define("_MD_THANKS_BUT_ERROR","از ارسال شما متشکریم. هم اکنون, به  دلیل یک  <span style=\"color:red\">خطا</span> نوشته شما منتشر نشد. از این مسئله متاسفیم. لطفا با مدیر سایت تماس بگیرید.");
define("_MD_USE_HTML","فعال کردن HTML");
define("_MD_USE_SMILEY","فعال کردن لبخند ها");
define("_MD_USE_BR","فعال کردن خط های auto wrap");
define("_MD_USE_XCODE","فعال کردن کد های زوپس");
define("_MD_NO_TOPICS","هیچ شاخه ای موجود نیست.");
define("_MD_TOPIC_IMAGE","تصور شاخه"); // ver 2.00 added
define("_MD_TOPIC_DISABLE","تصویر شاخه را نمایش نده"); // ver 2.00 added
define("_MD_TOPIC_LEFT","نمایش تصویر شاخه در سمت چپ"); // ver 2.00 added
define("_MD_TOPIC_RIGHT","نمایش تصویر شاخه در سمت راست"); // ver 2.00 added
define("_MD_PUBINHOME","انتشار در صفحه اصلی"); // ver 2.00 added
define("_MD_PUBLISHED","زمان ارسال"); // ver 2.00 added
define("_MD_EXPIRED","انقضا"); // ver 2.00 added
define("_MD_SETDATETIME","تنظیم زمان انتشار"); // ver 2.00 added
define("_MD_SETDATETIME_DESC","* اگر شما این گزینه را تنظیم نکنید, زمان انتشار همان زمان  ارسال خبر است."); // ver 2.00 added
define("_MD_SETEXPDATETIME","زمان انقضا را مشخص کنید"); // ver 2.00 added
define("_MD_SETEXPDATETIME_DESC","* اگر این مورد را تنظیم نکنید,  از زمان انقضا استفاده نمیشود."); // ver 2.00 added
define("_MD_APPROVE","تایید خودکار این خبر"); // ver 2.00 added
define("_MD_DATE_FORMAT","%d %m %y %h : %i : %s"); // ver 2.00 added
define("_MD_DBPUDATED","پایگاه داده ها با موفقیت به روز شد!"); // ver 2.00 added
define("_MD_POSTEDBY","فرستنده"); // ver 2.00 added
define("_MD_RELATION","نوشته های وابسته"); // ver 2.00 added
define("_MD_ADD_RELATION","اضافه کردن نوشته وابسته"); // ver 2.00 added
define("_MD_CHECKED_AS_RELATION","اضافه کردن مانند اخبار وابسته"); // ver 2.00 added
define("_MD_DISP_BLOCK","نمایش در بلاک"); // ver 2.00 added
define("_MD_RUSUREDEL","آیا شما میخواهید این خبر و نظر های زیر آن را حذف کنید؟"); // ver 2.00 added
define("_MD_EMPTYNODELETE", "نا توان در حذف."); // ver 2.00 added
//          archive.php          //
define("_MD_NEWSARCHIVES","آرشیو اخبار");
define("_MD_ARTICLES","اخبار");
define("_MD_VIEWS","بازدید ها");
define("_MD_DATE","زمان");
define("_MD_ACTIONS","");
define("_MD_PRINTERFRIENDLY","صفحه پرینت خبر");
define("_MD_THEREAREINTOTAL","در مجموع %s  نوشته موجود است.");
define("_MD_INTARTICLE","I have found an interesting news at %s");// %s is your site name
define("_MD_INTARTFOUND","Here is the really interesting news I found at %s:");
define("_MD_TOPICC","شاخه:");
define("_MD_URL","لینک:");
define("_MD_NOSTORY","متاسفانه نوشته انتخاب شده موجود نیست .");
define("_MD_YEAR_X","%s");
define("_MD_NO_ARCIVES","هیچ آرشیوی موجود نیست.");
define("_MD_JANUARY","January");
define("_MD_FEBRUARY","February");
define("_MD_MARCH","March");
define("_MD_APRIL","April");
define("_MD_MAY","May");
define("_MD_JUNE","June");
define("_MD_JULY","July");
define("_MD_AUGUST","August");
define("_MD_SEPTEMBER","September");
define("_MD_OCTOBER","October");
define("_MD_NOVEMBER","November");
define("_MD_DECEMBER","December");

//          print.php          //
define("_MD_URLFORSTORY","آدرس این خبر:");
define("_MD_THISCOMESFROM","خبر های بیشتر را بخوانید در %s.");// %s represents your site name

//          header.php          //
define("_MD_RSS", "RSS");
define("_MD_ARCHIVES","آرشیو"); // ver 2.00 added
?>

==> bulletinHD-2.2.zip: xoops_trust_path/modules/bulletin/language/persian/main.php <==
<?php /* English Translation by Marcelo Yuji Himoro <http://yuji.ws> */

//          index.php          //

// Appended by Xoops Language Checker -GIJOE- in 2009-08-26 16:24:56
define('_MD_INPUTHELPER','راهنمای ورود روشن/خاموش');
define('_MD_FCKXOOPS_ONOFF','ویرایشگر FCK روشن/خاموش (توجه: هیچ کدام از ویرایشگر ها نمیتوانند متن را منتشر کنند)');
define('_MD_ERROR_REQUIRED','{0} فیلد لازم است.');

define("_MD_PRINTER","صفحه پرینت خبر");
define("_MD_SENDSTORY","ارسال این خبر برای دوستان");
define("_MD_READMORE","ادامه نوشته...");
define("_MD_COMMENTS","0 نظر");
define("_MD_ONECOMMENT","1 نظر");
define("_MD_BYTESMORE","%s بیت در ادامه");
define("_MD_NUMCOMMENTS","%s نظر");

//          submit.php          //
define("_MD_SUBMITNEWS","ارسال خبر");
define("_MD_TITLE","موضوع");
define("_MD_TOPIC","شاخه");
define("_MD_THESCOOP","متن خبر");
define("_MD_NOTIFYPUBLISH","وقتی این خبر تایید شد مرا با ایمیل مطلع کن");
define("_MD_POST","پست");
define("_MD_GO","ارسال");
define("_MD_THANKS","نوشته شما دریافت شد. لطفا  صبر کنید تا مدیر سایت آن را برسی و تایید و منتشر کند."); //submission of news article
define("_MD_THANKS_AUTOAPPROVE","از ارسال شما متشکریم.");
define("_MD_THANKS_BUT_ERROR","از ارسال شما متشکریم. هم اکنون, به  دلیل یک  <span style=\"color:red\">خطا</span> نوشته شما منتشر نشد. از این مسئله متاسفیم. لطفا با مدیر سایت تماس بگیرید.");
define("_MD_USE_HTML","فعال کردن HTML");
define("_MD_USE_SMILEY","فعال کردن لبخند ها");
define("_MD_USE_BR","فعال کردن خط های auto wrap");
define("_MD_USE_XCODE","فعال کردن کد های زوپس");
define("_MD_NO_TOPICS","هیچ شاخه ای موجود نیست.");
define("_MD_TOPIC_IMAGE","تصور شاخه"); // ver 2.00 added
define("_MD_TOPIC_DISABLE","تصویر شاخه را نمایش نده"); // ver 2.00 added
define("_MD_TOPIC_LEFT","نمایش تصویر شاخه در سمت چپ"); // ver 2.00 added
define("_MD_TOPIC_RIGHT","نمایش تصویر شاخه در سمت راست"); // ver 2.00 added
define("_MD_PUBINHOME","انتشار در صفحه اصلی"); // ver 2.00 added
define("_MD_PUBLISHED","زمان ارسال"); // ver 2.00 added
define("_MD_EXPIRED","انقضا"); // ver 2.00 added
define("_MD_SETDATETIME","تنظیم زمان انتشار"); // ver 2.00 added
define("_MD_SETDATETIME_DESC","* اگر شما این گزینه را تنظیم نکنید, زمان انتشار همان زمان  ارسال خبر است."); // ver 2.00 added
define("_MD_SETEXPDATETIME","زمان انقضا را مشخص کنید"); // ver 2.00 added
define("_MD_SETEXPDATETIME_DESC","* اگر این مورد را تنظیم نکنید,  از زمان انقضا استفاده نمیشود."); // ver 2.00 added
define("_MD_APPROVE","تایید خودکار این خبر"); // ver 2.00 added
define("_MD_DATE_FORMAT","%d %m %y %h : %i : %s"); // ver 2.00 added
define("_MD_DBPUDATED","پایگاه داده ها با موفقیت به روز شد!"); // ver 2.00 added
define("_MD_POSTEDBY","فرستنده"); // ver 2.00 added
define("_MD_RELATION","نوشته های وابسته"); // ver 2.00 added
define("_MD_ADD_RELATION","اضافه کردن نوشته وابسته"); // ver 2.00 added
define("_MD_CHECKED_AS_RELATION","اضافه کردن مانند اخبار وابسته"); // ver 2.00 added
define("_MD_DISP_BLOCK","نمایش در بلاک"); // ver 2.00 added
define("_MD_RUSUREDEL","آیا شما میخواهید این خبر و نظر های زیر آن را حذف کنید؟"); // ver 2.00 added
define("_MD_EMPTYNODELETE", "نا توان در حذف."); // ver 2.00 added
//          archive.php          //
define("_MD_NEWSARCHIVES","آرشیو اخبار");
define("_MD_ARTICLES","اخبار");
define("_MD_VIEWS","بازدید ها");
define("_MD_DATE","زمان");
define("_MD_ACTIONS","");
define("_MD_PRINTERFRIENDLY","صفحه پرینت خبر");
define("_MD_THEREAREINTOTAL","در مجموع %s  نوشته موجود است.");
define("_MD_INTARTICLE","I have found an interesting news at %s");// %s is your site name
define("_MD_INTARTFOUND","Here is the really interesting news I found at %s:");
define("_MD_TOPICC","شاخه:");
define("_MD_URL","لینک:");
define("_MD_NOSTORY","متاسفانه نوشته انتخاب شده موجود نیست .");
define("_MD_YEAR_X","%s");
define("_MD_NO_ARCIVES","هیچ آرشیوی موجود نیست.");
define("_MD_JANUARY","January");
define("_MD_FEBRUARY","February");
define("_MD_MARCH","March");
define("_MD_APRIL","April");
define("_MD_MAY","May");
define("_MD_JUNE","June");
define("_MD_JULY","July");
define("_MD_AUGUST","August");
define("_MD_SEPTEMBER","September");
define("_MD_OCTOBER","October");
define("_MD_NOVEMBER","November");
define("_MD_DECEMBER","December");

//          print.php          //
define("_MD_URLFORSTORY","آدرس این خبر:");
define("_MD_THISCOMESFROM","خبر های بیشتر را بخوانید در %s.");// %s represents your site name

//          header.php          //
define("_MD_RSS", "RSS");
define("_MD_ARCHIVES","آرشیو"); // ver 2.00 added
?>
